@@ -15,29 +15,35 @@
  * License along with this program; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
+
+// own
 #include "bomber.h"
 
-#include "bomberwidget.h"
-#include "settings.h"
-
+// Qt
 #include <QAction>
+#include <QLabel>
+#include <QStatusBar>
+
+// KDE
 #include <KActionCollection>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <krandom.h>
-#include <KToggleAction>
-#include <QStatusBar>
-#include <QLabel>
-#include <kstandardgameaction.h>
+#include <KRandom>
 #include <KScoreDialog>
-#include <kgthemeselector.h>
+#include <KStandardGameAction>
+#include <KToggleAction>
+#include <KgThemeSelector>
+
+// Bomber
+#include "bomberwidget.h"
+#include "settings.h"
 
 Bomber::Bomber()
 {
     m_provider.discoverThemes(
         "appdata", QLatin1String("themes"), //theme data location
-        QLatin1String("kbomber")            //default theme name
-    );
+        QLatin1String("kbomber")); //default theme name
+
     m_selector = new KgThemeSelector(&m_provider);
 
     m_statusBar = statusBar();
@@ -87,9 +93,9 @@ void Bomber::initXMLUI()
     KStandardAction::preferences(m_selector, SLOT(showAsDialog()), actionCollection());
     m_soundAction = new KToggleAction(i18nc("Menu item used to disable or enable sound", "&Play Sounds"), this);
     actionCollection()->addAction(QLatin1String("toggle_sound"), m_soundAction);
-    connect(m_soundAction, &KToggleAction::triggered, this, &Bomber::setSounds);
+    connect(m_soundAction, &KToggleAction::triggered, m_gameWidget, &BomberGameWidget::setSoundsEnabled);
 
-    QAction *dropBombAction = actionCollection()->addAction(QLatin1String("drop_bomb"));
+    QAction * dropBombAction = actionCollection()->addAction(QLatin1String("drop_bomb"));
     dropBombAction->setText(i18nc("The name of the action used for dropping bombs", "&Drop bomb"));
     dropBombAction->setToolTip(i18nc("The tool tip text for the action used to drop bombs", "Drop bomb"));
     dropBombAction->setWhatsThis(i18nc("Description of the action used to drop bombs",
@@ -110,7 +116,7 @@ void Bomber::newGame()
     // Check for running game
     closeGame();
     if (m_gameWidget->state() == BomberGameWidget::State::BeforeFirstGame
-            || m_gameWidget->state() == BomberGameWidget::State::GameOver) {
+        || m_gameWidget->state() == BomberGameWidget::State::GameOver) {
         m_gameWidget->newGame();
     }
 }
@@ -127,7 +133,7 @@ void Bomber::pauseGame()
 void Bomber::closeGame()
 {
     if (m_gameWidget->state() == BomberGameWidget::State::BeforeFirstGame
-            || m_gameWidget->state() == BomberGameWidget::State::GameOver) {
+        || m_gameWidget->state() == BomberGameWidget::State::GameOver) {
         return;
     }
 
@@ -135,8 +141,9 @@ void Bomber::closeGame()
     if (old_state == BomberGameWidget::State::Running) {
         m_gameWidget->setPaused(true);
     }
-    int ret = KMessageBox::questionYesNo(this, i18nc("Message displayed when play tries to quit a game that is currently running",
-                                         "Do you really want to close the running game?"), QString(),
+    int ret = KMessageBox::questionYesNo(this, i18nc("Message displayed when player tries to quit a game that is currently running",
+                                                     "Do you really want to close the running game?"),
+                                         QString(),
                                          KStandardGuiItem::close(), KStandardGuiItem::cancel());
     if (ret == KMessageBox::Yes) {
         m_gameWidget->closeGame();
@@ -145,9 +152,6 @@ void Bomber::closeGame()
     }
 }
 
-/**
- * Bring up the standard kde high score dialog.
- */
 void Bomber::showHighscore()
 {
     KScoreDialog ksdialog(KScoreDialog::Name | KScoreDialog::Score | KScoreDialog::Level, this);
@@ -156,61 +160,62 @@ void Bomber::showHighscore()
 
 void Bomber::highscore()
 {
+    const unsigned int score = m_gameWidget->score();
+
     QPointer<KScoreDialog> ksdialog = new KScoreDialog(KScoreDialog::Name | KScoreDialog::Score | KScoreDialog::Level, this);
 
     KScoreDialog::FieldInfo info;
-    info[KScoreDialog::Score].setNum(m_gameWidget->score());
+    info[KScoreDialog::Score].setNum(score);
     info[KScoreDialog::Level].setNum(m_gameWidget->level());
-    if (ksdialog->addScore(info)) {
+    if (score > 0 && ksdialog->addScore(info) > 0) {
+        QString const message = i18n("Congratulations!\nYou made it into the hall of fame.");
+        ksdialog->setComment(message);
         ksdialog->exec();
+    } else {
+        QString const message = i18n("You gained a score of %1 point.", score);
+        KMessageBox::information(this, message, i18n("End of Game"));
     }
     delete ksdialog;
 }
 
-void Bomber::setSounds(bool val)
-{
-    BomberSettings::setPlaySounds(val);
-    m_gameWidget->settingsChanged();
-}
-
 void Bomber::displayLevel(unsigned int level)
 {
     m_level->setText(i18nc(
-                         "Used to display the current level of play to the user",
-                         "Level: %1", level));
+        "Used to display the current level of play to the user",
+        "Level: %1", level));
 }
 
 void Bomber::displayScore(unsigned int score)
 {
     m_score->setText(i18nc(
-                         "Used to inform the user of their current score", "Score: %1",
-                         score));
+        "Used to inform the user of their current score", "Score: %1",
+        score));
 }
 
 void Bomber::displayLives(unsigned int lives)
 {
     m_lives->setText(i18nc(
-                         "Used to tell the user how many lives they have left", "Lives: %1",
-                         lives));
+        "Used to tell the user how many lives they have left", "Lives: %1",
+        lives));
 }
 
 void Bomber::gameStateChanged(BomberGameWidget::State state)
 {
     switch (state) {
-    case BomberGameWidget::State::Paused:
-        m_pauseAction->setChecked(true);
-        m_statusBar->clearMessage();
-        break;
-    case BomberGameWidget::State::Running:
-        m_pauseAction->setChecked(false);
-        m_statusBar->clearMessage();
-        break;
-    case BomberGameWidget::State::GameOver:
-        m_statusBar->showMessage(i18nc("Game over messaged displayed in the status bar", "Game over. Press '%1' for a new game",
-                                       m_newAction->shortcuts().first().toString(QKeySequence::NativeText)));
-        highscore();
-        break;
-    default:
-        break;
+        case BomberGameWidget::State::Paused:
+            m_pauseAction->setChecked(true);
+            m_statusBar->clearMessage();
+            break;
+        case BomberGameWidget::State::Running:
+            m_pauseAction->setChecked(false);
+            m_statusBar->clearMessage();
+            break;
+        case BomberGameWidget::State::GameOver:
+            m_statusBar->showMessage(i18nc("Game over messaged displayed in the status bar", "Game over. Press '%1' for a new game",
+                                           m_newAction->shortcuts().first().toString(QKeySequence::NativeText)));
+            highscore();
+            break;
+        default:
+            break;
     }
 }
